@@ -6,6 +6,7 @@ mod use_is_first_mount;
 mod use_is_mounted;
 mod use_mount;
 mod use_timeout;
+mod use_title;
 mod use_toggle;
 mod use_unmount;
 mod use_update;
@@ -18,6 +19,7 @@ pub use use_is_first_mount::*;
 pub use use_is_mounted::*;
 pub use use_mount::*;
 pub use use_timeout::*;
+pub use use_title::*;
 pub use use_toggle::*;
 pub use use_unmount::*;
 pub use use_update::*;
